@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Infoblox Inc.
+# Copyright (c) 2021 Infoblox Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,6 +17,7 @@ import functools
 import netaddr
 import sys
 
+from neutron_lib.plugins import directory
 from oslo_log import log as logging
 from oslo_utils import excutils
 
@@ -24,7 +25,6 @@ from neutron.ipam import driver
 from neutron.ipam import exceptions as ipam_exc
 from neutron.ipam import requests as ipam_req
 from neutron.ipam import subnet_alloc
-from neutron import manager
 
 from infoblox_client import exceptions as ib_exc
 from infoblox_client import objects as ib_objects
@@ -50,9 +50,11 @@ def catch_ib_client_exception(f):
         try:
             return f(*args, **kwargs)
         except ib_exc.InfobloxException as e:
-            raise exc.InfobloxClientException(msg=e), None, sys.exc_info()[2]
+            raise exc.InfobloxClientException(
+                msg=e).with_traceback(sys.exc_info()[2])
         except ValueError as e:
-            raise exc.InfobloxValueError(msg=e), None, sys.exc_info()[2]
+            raise exc.InfobloxValueError(msg=e).with_traceback(
+                sys.exc_info()[2])
     return func
 
 
@@ -86,7 +88,7 @@ class InfobloxPool(subnet_alloc.SubnetAllocator):
     @catch_ib_client_exception
     def __init__(self, subnetpool, context):
         super(InfobloxPool, self).__init__(subnetpool, context)
-        self._plugin = manager.NeutronManager.get_plugin()
+        self._plugin = directory.get_plugin()
         self._grid_manager = grid.GridManager(self._context)
         self._grid_manager.get_config()
         self._grid_config = self._grid_manager.grid_config
@@ -111,9 +113,8 @@ class InfobloxPool(subnet_alloc.SubnetAllocator):
 
         ipam_controller = ipam.IpamSyncController(ib_cxt)
         ib_network = ipam_controller.get_subnet()
-        if ib_network:
-            return InfobloxSubnet(subnet_request, neutron_subnet, ib_network,
-                                  ib_cxt)
+        return InfobloxSubnet(subnet_request, neutron_subnet, ib_network,
+                              ib_cxt)
 
     @staticmethod
     def _build_request_from_subnet(neutron_subnet):
@@ -180,7 +181,6 @@ class InfobloxPool(subnet_alloc.SubnetAllocator):
         ib_network = self._create_ib_network(rollback_list, ipam_controller)
         if ib_network:
             dns_controller.create_dns_zones(rollback_list)
-            LOG.info("Created DNS zones.")
 
         return InfobloxSubnet(subnet_request, neutron_subnet, ib_network,
                               ib_cxt)
@@ -354,6 +354,21 @@ class InfobloxSubnet(driver.Subnet):
             raise ValueError("Subnet details should be passed as "
                              "SpecificSubnetRequest")
 
+    def _validate_network_availability(self):
+        ib_network = None
+        try:
+            ib_network = (
+                ib_objects.Network.search(
+                    self._ib_cxt.connector,
+                    network_view=self._ib_network.network_view,
+                    cidr=self._neutron_subnet['cidr']))
+        except Exception as e:
+            LOG.error(_LE("Exception occured: %(error)s while"
+                          "searching network %(network)s"),
+                      {'error': e,
+                       'network': self._neutron_subnet['cidr']})
+        return ib_network
+
     @catch_ib_client_exception
     def allocate(self, address_request):
         """Allocate an IP address based on the request passed in.
@@ -362,6 +377,20 @@ class InfobloxSubnet(driver.Subnet):
         :type address_request: A subclass of AddressRequest
         :returns: A netaddr.IPAddress
         """
+        # Validate if network is available for which port
+        # association request came.
+        # This handle case where subnet is in process of deletion and
+        # port allocation comes for update_port.
+        if not self._ib_network:
+            raise Exception("IB Network: %s not Found in the NIOS" % (
+                            self._neutron_subnet['cidr']))
+
+        if not self._validate_network_availability():
+            raise Exception(
+                "IB Network: %s not Found under Network View: %s" % (
+                    self._neutron_subnet['cidr'],
+                    self._ib_network.network_view))
+
         ipam_controller = ipam.IpamSyncController(self._ib_cxt)
         dns_controller = dns.DnsController(self._ib_cxt)
 
@@ -399,7 +428,9 @@ class InfobloxSubnet(driver.Subnet):
                                           port_name=port_name)
             except Exception:
                 with excutils.save_and_reraise_exception():
-                    ipam_controller.deallocate_ip(allocated_ip)
+                    ipam_controller.deallocate_ip(
+                        allocated_ip,
+                        address_request.device_owner)
 
         return allocated_ip
 
@@ -411,6 +442,9 @@ class InfobloxSubnet(driver.Subnet):
         :type address: A subclass of netaddr.IPAddress or convertible to one.
         :returns: None
         """
+        if not self._ib_network:
+            return
+
         ip_addr = str(address)
         address_request = self._build_address_request_from_ib_address(ip_addr)
         if not address_request:
@@ -419,7 +453,7 @@ class InfobloxSubnet(driver.Subnet):
         ipam_controller = ipam.IpamSyncController(self._ib_cxt)
         dns_controller = dns.DnsController(self._ib_cxt)
 
-        ipam_controller.deallocate_ip(ip_addr)
+        ipam_controller.deallocate_ip(ip_addr, address_request.device_owner)
         port_name = (address_request.port_name
                      if hasattr(address_request, 'port_name')
                      else None)
