@@ -14,8 +14,7 @@
 #    under the License.
 
 from neutron_lib import constants as n_const
-
-from neutron.plugins.common import constants as p_const
+from neutron_lib.plugins import constants as p_const
 
 
 CLOUD_PLATFORM_NAME = 'OpenStack'
@@ -161,6 +160,8 @@ IS_DEFAULT = 'is_default'
 NEUTRON_DEVICE_OWNER_TO_PATTERN_MAP = {
     n_const.DEVICE_OWNER_DHCP: 'dhcp-port-{ip_address}',
     n_const.DEVICE_OWNER_ROUTER_INTF: 'router-iface-{ip_address}',
+    n_const.DEVICE_OWNER_ROUTER_HA_INTF: 'router-ha-iface-{ip_address}',
+    n_const.DEVICE_OWNER_HA_REPLICATED_INT: 'router-ha-iface-{ip_address}',
     n_const.DEVICE_OWNER_ROUTER_GW: 'router-gw-{ip_address}',
     n_const.DEVICE_OWNER_FLOATINGIP: 'floating-ip-{ip_address}',
     'neutron:' + p_const.LOADBALANCER: 'lb-vip-{ip_address}'
@@ -169,6 +170,8 @@ NEUTRON_DEVICE_OWNER_TO_PATTERN_MAP = {
 NEUTRON_INTERNAL_SERVICE_DEVICE_OWNERS = [
     n_const.DEVICE_OWNER_DHCP,
     n_const.DEVICE_OWNER_ROUTER_INTF,
+    n_const.DEVICE_OWNER_ROUTER_HA_INTF,
+    n_const.DEVICE_OWNER_HA_REPLICATED_INT,
     n_const.DEVICE_OWNER_ROUTER_GW,
     'neutron:' + p_const.LOADBALANCER
 ]
@@ -264,24 +267,24 @@ REQUIRED_EA_DEFS = [
 
     # Grid Configuration EAs
     {'name': EA_GRID_CONFIG_GRID_SYNC_SUPPORT,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_GRID_SYNC_MINIMUM_WAIT_TIME,
-     'type': 'INTEGER', 'flags': '',
+     'type': 'INTEGER', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_GRID_SYNC_MAXIMUM_WAIT_TIME,
-     'type': 'INTEGER', 'flags': '',
+     'type': 'INTEGER', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DEFAULT_NETWORK_VIEW_SCOPE,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': NETWORK_VIEW_SCOPE_SINGLE},
                      {'value': NETWORK_VIEW_SCOPE_ADDRESS_SCOPE},
@@ -291,132 +294,132 @@ REQUIRED_EA_DEFS = [
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DEFAULT_NETWORK_VIEW,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DEFAULT_HOST_NAME_PATTERN,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DEFAULT_DOMAIN_NAME_PATTERN,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_EXTERNAL_HOST_NAME_PATTERN,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_EXTERNAL_DOMAIN_NAME_PATTERN,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_NS_GROUP,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DNS_VIEW,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_NETWORK_TEMPLATE,
-     'type': 'STRING', 'flags': '',
+     'type': 'STRING', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_ADMIN_NETWORK_DELETION,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_IP_ALLOCATION_STRATEGY,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': IP_ALLOCATION_STRATEGY_HOST_RECORD},
                      {'value': IP_ALLOCATION_STRATEGY_FIXED_ADDRESS}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DNS_RECORD_BINDING_TYPES,
-     'type': 'STRING', 'flags': 'V',
+     'type': 'STRING', 'flags': 'CGV',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DNS_RECORD_UNBINDING_TYPES,
-     'type': 'STRING', 'flags': 'V',
+     'type': 'STRING', 'flags': 'CGV',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DNS_RECORD_REMOVABLE_TYPES,
-     'type': 'STRING', 'flags': 'V',
+     'type': 'STRING', 'flags': 'CGV',
      'allowed_object_types': ['Member'],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DHCP_SUPPORT,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_DNS_SUPPORT,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_RELAY_SUPPORT,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_USE_GM_FOR_DHCP,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_TENANT_NAME_PERSISTENCE,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_REPORT_GRID_SYNC_TIME,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_ALLOW_SERVICE_RESTART,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_ALLOW_STATIC_ZONE_DELETION,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
      'comment': 'Grid Configuration'},
 
     {'name': EA_GRID_CONFIG_ZONE_CREATION_STRATEGY,
-     'type': 'ENUM', 'flags': 'V',
+     'type': 'ENUM', 'flags': 'CGV',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': ZONE_CREATION_STRATEGY_FORWARD},
                      {'value': ZONE_CREATION_STRATEGY_REVERSE}],
@@ -476,7 +479,7 @@ REQUIRED_EA_DEFS = [
 
     # Member Registration EA
     {'name': EA_IS_CLOUD_MEMBER,
-     'type': 'ENUM', 'flags': '',
+     'type': 'ENUM', 'flags': 'CG',
      'allowed_object_types': ['Member'],
      'list_values': [{'value': 'True'},
                      {'value': 'False'}],
