@@ -14,10 +14,9 @@
 #    under the License.
 
 from collections import Counter
+from neutron_lib.plugins import directory
 from oslo_log import log as logging
 
-from neutron import manager
-
 from infoblox_client import connector
 
 from infoblox_client import object_manager as obj_mgr
@@ -42,7 +41,7 @@ class InfobloxContext(object):
                  mapping_conditions=None, ib_network=None):
         self.context = neutron_context
         self.user_id = user_id
-        self.plugin = plugin if plugin else manager.NeutronManager.get_plugin()
+        self.plugin = plugin if plugin else directory.get_plugin()
         self.network = network if network else {}
         self.subnet = subnet if subnet else {}
         self.ib_network = ib_network
@@ -115,14 +114,13 @@ class InfobloxContext(object):
 
         if self.grid_config.tenant_name_persistence:
             # Try resync with keystone if still no tenant name is found
-            if km.sync_tenants_from_keystone(self.context,
-                                             self.context.auth_token):
+            if km.sync_tenants_from_keystone(self.context):
                 tenant = dbi.get_tenant(self.context.session,
                                         tenant_id_in_query)
                 if tenant:
                     return tenant.tenant_name
         else:
-            tenants = km.get_all_tenants(self.context.auth_token)
+            tenants = km.get_all_tenants()
             for tenant in tenants:
                 if tenant.id == tenant_id_in_query:
                     return tenant.name
@@ -617,7 +615,7 @@ class InfobloxContext(object):
         # find mapping matches on common cases
         mapping_filters = self._get_mapping_filters(mapping_attrs)
         for mf in mapping_filters:
-            if mf.values()[0] is None:
+            if list(mf.values())[0] is None:
                 continue
             matches = utils.find_in_list_by_condition(
                 mf, self.discovered_mapping_conditions)
