@@ -14,6 +14,7 @@
 #    under the License.
 
 from infoblox_client import exceptions as ibc_exc
+from infoblox_client import objects as obj
 from neutron_lib import constants as n_const
 from oslo_log import log as logging
 from oslo_utils import excutils
@@ -59,7 +60,7 @@ class DnsController(object):
     def create_dns_zones(self, rollback_list):
         if self.grid_config.dns_support is False:
             return
-
+        LOG.debug("Initialized DNS Zone creation")
         cidr = self.ib_cxt.subnet['cidr']
         subnet_name = self.ib_cxt.subnet['name']
         dns_view = self.ib_cxt.mapping.dns_view
@@ -72,41 +73,62 @@ class DnsController(object):
         if ns_group:
             # create Forward zone
             if self.need_forward:
-                ib_zone = self.ib_cxt.ibom.create_dns_zone(
-                    dns_view,
-                    self.dns_zone,
+                ib_zone, obj_created = obj.DNSZone.create_check_exists(
+                    self.ib_cxt.connector,
+                    view=dns_view,
                     ns_group=ns_group,
+                    fqdn=self.dns_zone,
                     extattrs=self.forward_zone_eas)
-                rollback_list.append(ib_zone)
+                if ib_zone and obj_created:
+                    LOG.info("Created forward zone: %s with ns_group: %s" % (
+                             self.dns_zone, ns_group))
+                    rollback_list.append(ib_zone)
+
             # create Reverse zone
             if self.need_reverse:
-                ib_zone_cidr = self.ib_cxt.ibom.create_dns_zone(
-                    dns_view,
-                    cidr,
+                ib_zone_cidr, obj_created = obj.DNSZone.create_check_exists(
+                    self.ib_cxt.connector,
+                    view=dns_view,
+                    fqdn=cidr,
                     prefix=prefix,
                     zone_format=zone_format,
                     extattrs=self.reverse_zone_eas)
-                rollback_list.append(ib_zone_cidr)
+                if ib_zone_cidr and obj_created:
+                    LOG.info("Created reverse zone: %s with ns_group: %s" % (
+                             cidr, ns_group))
+                    rollback_list.append(ib_zone_cidr)
         else:
             # create Forward zone
             if self.need_forward:
-                ib_zone = self.ib_cxt.ibom.create_dns_zone(
-                    dns_view,
-                    self.dns_zone,
+                ib_zone, obj_created = obj.DNSZone.create_check_exists(
+                    self.ib_cxt.connector,
+                    view=dns_view,
+                    fqdn=self.dns_zone,
                     grid_primary=grid_primaries,
                     grid_secondaries=grid_secondaries,
                     extattrs=self.forward_zone_eas)
-                rollback_list.append(ib_zone)
+                if ib_zone and obj_created:
+                    LOG.info("Created forward zone: %s with "
+                             "grid_primaries: %s, grid_secondaries: %s" % (
+                                 self.dns_zone, grid_primaries,
+                                 grid_secondaries))
+                    rollback_list.append(ib_zone)
+
             # create Reverse zone
             if self.need_reverse:
-                ib_zone_cidr = self.ib_cxt.ibom.create_dns_zone(
-                    dns_view,
-                    cidr,
+                ib_zone_cidr, obj_created = obj.DNSZone.create_check_exists(
+                    self.ib_cxt.connector,
+                    view=dns_view,
+                    fqdn=cidr,
                     grid_primary=grid_primaries,
                     prefix=prefix,
                     zone_format=zone_format,
                     extattrs=self.reverse_zone_eas)
-                rollback_list.append(ib_zone_cidr)
+                if ib_zone_cidr and obj_created:
+                    LOG.info("Created reverse zone: %s with "
+                             "grid_primaries: %s, grid_secondaries: %s" % (
+                                 cidr, grid_primaries, grid_secondaries))
+                    rollback_list.append(ib_zone_cidr)
 
     def update_dns_zones(self):
         if self.grid_config.dns_support is False:
@@ -221,8 +243,10 @@ class DnsController(object):
                     else self.ib_cxt.ip_alloc)
         try:
             self._bind_names(ip_alloc.bind_names, ip_address,
-                             instance_name, port_id, port_tenant_id, device_id,
-                             device_owner, ea_ip_address, port_name)
+                             instance_name, port_id,
+                             port_tenant_id, device_id,
+                             device_owner, ea_ip_address,
+                             port_name, tenant_name)
         except ibc_exc.InfobloxCannotCreateObject:
             with excutils.save_and_reraise_exception():
                 self.unbind_names(ip_address, instance_name, port_id,
@@ -242,20 +266,74 @@ class DnsController(object):
                          instance_name, port_id, port_tenant_id, device_id,
                          device_owner, port_name=port_name, unbind=True)
 
+    def _ensure_dns_zone_availability(self, dns_view, port_tenant_id,
+                                      tenant_name, is_external):
+
+        if self.grid_config.dns_support is False:
+            return
+
+        forward_zone_eas = eam.get_ea_for_forward_zone(
+            self.ib_cxt.user_id, port_tenant_id,
+            tenant_name, self.ib_cxt.network,
+            self.ib_cxt.subnet,
+            self.pattern_builder.get_zone_name(
+                is_external=self.ib_cxt.network_is_external))
+
+        dns_zone_name = self.pattern_builder.get_zone_name(
+            port_tenant_id=port_tenant_id,
+            tenant_name=tenant_name, is_external=is_external)
+
+        ns_group = self.grid_config.ns_group
+
+        if ns_group:
+            ib_zone, obj_created = obj.DNSZone.create_check_exists(
+                self.ib_cxt.connector,
+                view=dns_view,
+                ns_group=ns_group,
+                fqdn=dns_zone_name,
+                extattrs=forward_zone_eas)
+            if ib_zone and obj_created:
+                LOG.info("Created forward zone: %s with ns_group: %s" % (
+                         dns_zone_name, ns_group))
+
+        else:
+            self.ib_cxt.reserve_service_members()
+            grid_primaries, grid_secondaries = self.ib_cxt.get_dns_members()
+            ib_zone, obj_created = obj.DNSZone.create_check_exists(
+                self.ib_cxt.connector,
+                view=dns_view,
+                fqdn=dns_zone_name,
+                grid_primary=grid_primaries,
+                grid_secondaries=grid_secondaries,
+                extattrs=forward_zone_eas)
+            if ib_zone and obj_created:
+                LOG.info("Created forward zone: %s with "
+                         "grid_primaries: %s, grid_secondaries: %s" % (
+                             dns_zone_name, grid_primaries, grid_secondaries))
+
     def _bind_names(self, binding_func, ip_address, instance_name=None,
                     port_id=None, port_tenant_id=None, device_id=None,
                     device_owner=None, ea_ip_address=None, port_name=None,
-                    unbind=False):
+                    tenant_name=None, unbind=False):
         network_view = self.ib_cxt.mapping.network_view
         dns_view = self.ib_cxt.mapping.dns_view
         is_external = self.ib_cxt.network_is_external
 
+        # It ensure if dns zone is available at NIOS, if not
+        # then creates it.
+        if not unbind:
+            self._ensure_dns_zone_availability(dns_view, port_tenant_id,
+                                               tenant_name, is_external)
+
         fqdn = None
         try:
-            fqdn = self.pattern_builder.get_hostname(ip_address, instance_name,
-                                                     port_id, device_owner,
-                                                     device_id, port_name,
-                                                     external=is_external)
+            fqdn = self.pattern_builder.get_hostname(
+                ip_address, instance_name,
+                port_id, device_owner,
+                device_id, port_name,
+                external=is_external,
+                port_tenant_id=port_tenant_id,
+                tenant_name=tenant_name)
         except ibc_exc.InfobloxConfigException:
             # if unbind - just use fqdn=None to search by ip
             if not unbind:
