@@ -14,11 +14,10 @@
 #    under the License.
 
 from infoblox_client import objects as ib_objects
+from neutron_lib.api.definitions import provider_net as providernet
 from neutron_lib import constants as n_const
 
-from neutron.api.v2 import attributes
-from neutron.extensions import external_net
-from neutron.extensions import providernet
+from neutron_lib.api.definitions import external_net
 
 from networking_infoblox.neutron.common import constants as const
 from networking_infoblox.neutron.common import utils
@@ -103,7 +102,7 @@ def reset_ea_for_network(ib_network):
 
     eas = ib_network.extattrs
     ea_dict = eas.to_dict()
-    map(lambda ea: ea_dict.pop(ea, None), const.NETWORK_EA_LIST)
+    list(map(lambda ea: ea_dict.pop(ea, None), const.NETWORK_EA_LIST))
     ib_network.extattrs = ib_objects.EA.from_dict(ea_dict)
 
 
@@ -120,7 +119,7 @@ def reset_ea_for_range(ib_range):
 
     eas = ib_range.extattrs
     ea_dict = eas.to_dict()
-    map(lambda ea: ea_dict.pop(ea, None), const.RANGE_EA_LIST)
+    list(map(lambda ea: ea_dict.pop(ea, None), const.RANGE_EA_LIST))
     ib_range.extattrs = ib_objects.EA.from_dict(ea_dict)
 
 
@@ -183,14 +182,14 @@ def reset_ea_for_zone(ib_zone):
 
     eas = ib_zone.extattrs
     ea_dict = eas.to_dict()
-    map(lambda ea: ea_dict.pop(ea, None), const.ZONE_EA_LIST)
+    list(map(lambda ea: ea_dict.pop(ea, None), const.ZONE_EA_LIST))
     ib_zone.extattrs = ib_objects.EA.from_dict(ea_dict)
 
 
 def get_common_ea(network, user_id, tenant_id, tenant_name, for_network=False):
     if network:
         is_external = network.get(external_net.EXTERNAL, False)
-        is_shared = network.get(attributes.SHARED)
+        is_shared = network.get(n_const.SHARED)
     else:
         is_external = False
         is_shared = False
