@@ -21,6 +21,7 @@ from oslo_utils import uuidutils
 from neutron.ipam import exceptions as ipam_exc
 from neutron.ipam import utils as ipam_utils
 
+from infoblox_client import exceptions as ib_exc
 from infoblox_client import objects as ib_objects
 
 from networking_infoblox._i18n import _LI
@@ -77,8 +78,9 @@ class IpamSyncController(object):
 
         # create a network view if it does not exist
         if not network_view_exists:
-            ib_network_view = self._create_ib_network_view()
-            rollback_list.append(ib_network_view)
+            ib_network_view, obj_created = self._create_ib_network_view()
+            if ib_network_view and obj_created:
+                rollback_list.append(ib_network_view)
 
         ib_network, created = self._create_ib_network()
         if ib_network:
@@ -110,10 +112,11 @@ class IpamSyncController(object):
             self.ib_cxt.tenant_id,
             self.ib_cxt.tenant_name,
             self.grid_id)
-
-        ib_network_view = self.ib_cxt.ibom.create_network_view(
-            self.ib_cxt.mapping.network_view,
-            ea_network_view)
+        ib_network_view, obj_created = (
+            ib_objects.NetworkView.create_check_exists(
+                self.ib_cxt.connector,
+                name=self.ib_cxt.mapping.network_view,
+                extattrs=ea_network_view))
 
         network_view_id = utils.get_network_view_id(self.grid_id,
                                                     ib_network_view._ref)
@@ -123,7 +126,7 @@ class IpamSyncController(object):
         self.ib_cxt.mapping.network_view_id = network_view_id
 
         LOG.info(_LI("Created a network view: %s"), ib_network_view)
-        return ib_network_view
+        return ib_network_view, obj_created
 
     def _create_ib_network(self):
         network_view = self.ib_cxt.mapping.network_view
@@ -200,7 +203,11 @@ class IpamSyncController(object):
                                                  host_name=member_name,
                                                  return_fields=['host_name'])
             if ib_member:
-                self.ib_cxt.ibom.restart_all_services(ib_member)
+                try:
+                    self.ib_cxt.ibom.restart_all_services(ib_member)
+                except Exception as e:
+                    LOG.warning(("Restart all services for member: %r " +
+                                 "fails with error: %r") % (ib_member, e))
 
     def _register_mapping_member(self):
         session = self.ib_cxt.context.session
@@ -591,9 +598,14 @@ class IpamSyncController(object):
                     ea_ip_address)
                 if allocated_ip:
                     break
-            except exc.InfobloxCannotAllocateIp:
-                LOG.info("Failed to allocate IP from range (%s-%s)." %
-                         (first_ip, last_ip))
+            except ib_exc.InfobloxCannotAllocateIp as err:
+                LOG.info("Failed to allocate IP from range (%s-%s)"
+                         "with error: %r." % (first_ip, last_ip, err))
+                continue
+
+            except ib_exc.InfobloxCannotCreateObject as err:
+                LOG.info("Failed to create IP from range (%s-%s)"
+                         "with error: %r." % (first_ip, last_ip, err))
                 continue
 
         if allocated_ip:
@@ -608,11 +620,15 @@ class IpamSyncController(object):
 
         return allocated_ip
 
-    def deallocate_ip(self, ip_address):
+    def deallocate_ip(self, ip_address, device_owner=None):
         dns_view = self.ib_cxt.mapping.dns_view
-        self.ib_cxt.ip_alloc.deallocate_ip(self.ib_cxt.mapping.network_view,
-                                           dns_view,
-                                           ip_address)
+        ip_alloc = (self.ib_cxt.dhcp_port_ip_alloc
+                    if device_owner == n_const.DEVICE_OWNER_DHCP
+                    else self.ib_cxt.ip_alloc)
+
+        ip_alloc.deallocate_ip(self.ib_cxt.mapping.network_view,
+                               dns_view,
+                               ip_address)
 
     @staticmethod
     def _range_is_managed(ib_range):
