@@ -14,6 +14,8 @@
 #    under the License.
 
 import netaddr
+from neutron import manager
+from neutron_lib.plugins import directory
 from oslo_log import log as logging
 import oslo_messaging
 from oslo_utils import encodeutils
@@ -21,8 +23,6 @@ from sqlalchemy import exc as sql_exc
 
 from infoblox_client import objects as ib_objects
 
-from neutron import manager
-
 from networking_infoblox.neutron.common import constants as const
 from networking_infoblox.neutron.common import context
 from networking_infoblox.neutron.common import dns
@@ -42,7 +42,13 @@ class IpamEventHandler(object):
 
     def __init__(self, neutron_context, plugin=None, grid_manager=None):
         self.context = neutron_context
-        self.plugin = plugin if plugin else manager.NeutronManager.get_plugin()
+        # Check if neutron_manager is loaded as accessing directory methods
+        # before a Neutron Manager has had the chances to load the environment
+        # may result in callers handling an empty directory.
+        if not directory.is_loaded():
+            manager.init()
+
+        self.plugin = plugin if plugin else directory.get_plugin()
         if grid_manager:
             self.grid_mgr = grid_manager
         else:
@@ -75,7 +81,8 @@ class IpamEventHandler(object):
             handler_name = utils.get_notification_handler_name(event_type)
             handler = getattr(self, handler_name)
             if handler:
-                handler(payload)
+                with self.context.session.begin(subtransactions=True):
+                    handler(payload)
             return oslo_messaging.NotificationResult.HANDLED
         except sql_exc.OperationalError as e:
             LOG.info("Operational Error occurred. Please restart the agent.")
@@ -132,8 +139,7 @@ class IpamEventHandler(object):
             keystone_manager.update_tenant_mapping(self.context,
                                                    networks,
                                                    self.ctxt['tenant_id'],
-                                                   self.ctxt['tenant_name'],
-                                                   self.ctxt['auth_token'])
+                                                   self.ctxt['tenant_name'])
 
     def update_network_sync(self, payload):
         """Notifies that the network property has been updated."""
@@ -438,12 +444,12 @@ class IpamEventHandler(object):
         """Notifies that an instance has been created."""
         instance_id = payload.get('instance_id')
         instance_name = payload.get('hostname')
-        dbi.add_or_update_instance(self.context.session,
-                                   instance_id, instance_name)
         if self.traceable:
             LOG.info("Created instance: %s, host: %s",
                      instance_id, instance_name)
 
+        dbi.add_or_update_instance(self.context.session,
+                                   instance_id, instance_name)
         ips = payload.get('fixed_ips')
         if not ips:
             return
