@@ -13,11 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-from neutron_lib import constants as n_const
+import unittest.mock as mock
 
-from neutron import context
 from neutron.tests.unit import testlib_api
+from neutron_lib import constants as n_const
+from neutron_lib import context
 
 from infoblox_client import objects as ib_objects
 
@@ -70,107 +70,142 @@ class DnsControllerTestCase(base.TestCase, testlib_api.SqlTestCase):
         ib_cxt.grid_config.allow_static_zone_deletion = False
         return ib_cxt
 
-    def test_create_dns_zones_without_ns_group_both_zones(self):
+    @mock.patch.object(ib_objects, 'DNSZone')
+    def test_create_dns_zones_without_ns_group_zone_preexist(self,
+                                                             mock_zone_obj):
+        mock_zone_obj.create_check_exists.return_value = mock.Mock(), False
+        self._test_create_dns_zones_without_ns_group_both_zones(mock_zone_obj)
+
+    @mock.patch.object(ib_objects, 'DNSZone')
+    def test_create_dns_zones_without_ns_group_zone_created(self,
+                                                            mock_zone_obj):
+        mock_zone_obj.create_check_exists.return_value = mock.Mock(), True
+        self._test_create_dns_zones_without_ns_group_both_zones(mock_zone_obj)
+
+    def _test_create_dns_zones_without_ns_group_both_zones(self,
+                                                           mock_zone_obj):
         rollback_list = []
         # default strategy is to create both Forward and Reverse zones
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == [
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.test_dns_zone,
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.test_dns_zone,
                 grid_primary=[mock.ANY],
                 grid_secondaries=None,
                 extattrs=mock.ANY),
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.ib_cxt.subnet['cidr'],
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.ib_cxt.subnet['cidr'],
                 grid_primary=[mock.ANY],
                 prefix=None,
                 zone_format=self.test_zone_format,
                 extattrs=mock.ANY)
         ]
         self.ib_cxt.ibom.reset_mock()
+        mock_zone_obj.reset_mock()
 
         # check strategy with only Forward zone
         self.ib_cxt.grid_config.zone_creation_strategy = [
             constants.ZONE_CREATION_STRATEGY_FORWARD]
         self.controller._update_strategy_and_eas()
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == [
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.test_dns_zone,
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.test_dns_zone,
                 grid_primary=[mock.ANY],
                 grid_secondaries=None,
                 extattrs=mock.ANY),
         ]
         self.ib_cxt.ibom.reset_mock()
+        mock_zone_obj.reset_mock()
 
         # check strategy with only Reverse zone
         self.ib_cxt.grid_config.zone_creation_strategy = [
             constants.ZONE_CREATION_STRATEGY_REVERSE]
         self.controller._update_strategy_and_eas()
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == [
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.ib_cxt.subnet['cidr'],
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.ib_cxt.subnet['cidr'],
                 grid_primary=[mock.ANY],
                 prefix=None,
                 zone_format=self.test_zone_format,
                 extattrs=mock.ANY)
         ]
         self.ib_cxt.ibom.reset_mock()
+        mock_zone_obj.reset_mock()
 
         # check empty strategy
         self.ib_cxt.grid_config.zone_creation_strategy = []
         self.controller._update_strategy_and_eas()
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == []
+        assert mock_zone_obj.method_calls == []
 
-    def test_create_dns_zones_with_ns_group(self):
+    @mock.patch.object(ib_objects, 'DNSZone')
+    def test_create_dns_zones_with_ns_group_zone_preexist(self, mock_zone_obj):
+        mock_zone_obj.create_check_exists.return_value = mock.Mock(), False
+        self._test_create_dns_zones_with_ns_group(mock_zone_obj)
+
+    @mock.patch.object(ib_objects, 'DNSZone')
+    def test_create_dns_zones_with_ns_group_zone_created(self, mock_zone_obj):
+        mock_zone_obj.create_check_exists.return_value = mock.Mock(), True
+        self._test_create_dns_zones_with_ns_group(mock_zone_obj)
+
+    def _test_create_dns_zones_with_ns_group(self, mock_zone_obj):
         rollback_list = []
         # default strategy is to create both Forward and Reverse zones
         self.ib_cxt.grid_config.ns_group = 'test-ns-group'
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == [
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.test_dns_zone,
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.test_dns_zone,
                 ns_group=self.ib_cxt.grid_config.ns_group,
                 extattrs=mock.ANY),
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.ib_cxt.subnet['cidr'],
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.ib_cxt.subnet['cidr'],
                 prefix=None,
                 zone_format=self.test_zone_format,
                 extattrs=mock.ANY)
         ]
         self.ib_cxt.ibom.reset_mock()
-
+        mock_zone_obj.reset_mock()
         # check strategy with only Forward zone
         self.ib_cxt.grid_config.zone_creation_strategy = [
             constants.ZONE_CREATION_STRATEGY_FORWARD]
         self.controller._update_strategy_and_eas()
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == [
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.test_dns_zone,
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.test_dns_zone,
                 ns_group=self.ib_cxt.grid_config.ns_group,
                 extattrs=mock.ANY),
         ]
         self.ib_cxt.ibom.reset_mock()
+        mock_zone_obj.reset_mock()
 
         # check strategy with only Reverse zone
         self.ib_cxt.grid_config.zone_creation_strategy = [
             constants.ZONE_CREATION_STRATEGY_REVERSE]
         self.controller._update_strategy_and_eas()
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == [
-            mock.call.create_dns_zone(
-                self.ib_cxt.mapping.dns_view,
-                self.ib_cxt.subnet['cidr'],
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=self.ib_cxt.mapping.dns_view,
+                fqdn=self.ib_cxt.subnet['cidr'],
                 prefix=None,
                 zone_format=self.test_zone_format,
                 extattrs=mock.ANY)
@@ -178,10 +213,11 @@ class DnsControllerTestCase(base.TestCase, testlib_api.SqlTestCase):
 
         # check empty strategy
         self.ib_cxt.ibom.reset_mock()
+        mock_zone_obj.reset_mock()
         self.ib_cxt.grid_config.zone_creation_strategy = []
         self.controller._update_strategy_and_eas()
         self.controller.create_dns_zones(rollback_list)
-        assert self.ib_cxt.ibom.method_calls == []
+        assert mock_zone_obj.method_calls == []
 
     def _create_ib_zone_ea(self):
         zone_ea = {'CMP Type': {'value': 'OpenStack'},
@@ -413,6 +449,8 @@ class DnsControllerTestCase(base.TestCase, testlib_api.SqlTestCase):
 
     @mock.patch.object(dbi, 'get_instance', mock.Mock())
     @mock.patch.object(ea_manager, 'get_ea_for_ip', mock.Mock())
+    @mock.patch.object(dns.DnsController, '_ensure_dns_zone_availability',
+                       mock.Mock())
     def test_bind_names(self):
         ip_address = '11.11.1.2'
         instance_name = 'test-vm'
@@ -501,6 +539,8 @@ class DnsControllerTestCase(base.TestCase, testlib_api.SqlTestCase):
                 dbi.get_instance.assert_called_once_with(*dbi_call_params)
                 ea_manager.get_ea_for_ip.reset_mock()
 
+    @mock.patch.object(dns.DnsController, '_ensure_dns_zone_availability',
+                       mock.Mock())
     def test_unbind_names(self):
         ip_address = '11.11.1.2'
         instance_name = 'test-vm'
@@ -536,6 +576,8 @@ class DnsControllerTestCase(base.TestCase, testlib_api.SqlTestCase):
                                    None)
         ]
 
+    @mock.patch.object(dns.DnsController, '_ensure_dns_zone_availability',
+                       mock.Mock())
     def test_unbind_names_without_name(self):
         ip_address = '11.11.1.2'
         port_id = 'port-id'
@@ -594,3 +636,52 @@ class DnsControllerTestCase(base.TestCase, testlib_api.SqlTestCase):
 
     def test_update_dns_zones_empty(self):
         self._test_update_calls([], [])
+
+    @mock.patch.object(ib_objects, 'DNSZone')
+    @mock.patch.object(ea_manager, 'get_ea_for_forward_zone')
+    def test_ensure_dns_zone_with_ns_group_availability(
+            self, mock_eas_fw_zone, mock_zone_obj):
+        # default strategy is to create both Forward
+        self.ib_cxt.grid_config.ns_group = 'test-ns-group'
+        dns_view = 'test_dns_view'
+        port_tenant_id = 'test_tenant_id'
+        tenant_name = 'test_tenant_name'
+        is_external = 'false'
+        mock_zone_obj.create_check_exists.return_value = (
+            mock.Mock(), True)
+        mock_eas_fw_zone.return_value = 'test_eas_forward_zone'
+        self.controller._ensure_dns_zone_availability(
+            dns_view, port_tenant_id,
+            tenant_name, is_external)
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=dns_view,
+                fqdn=self.test_dns_zone,
+                ns_group=self.ib_cxt.grid_config.ns_group,
+                extattrs='test_eas_forward_zone')
+        ]
+
+    @mock.patch.object(ib_objects, 'DNSZone')
+    @mock.patch.object(ea_manager, 'get_ea_for_forward_zone')
+    def test_ensure_dns_zone_without_ns_group_availability(
+            self, mock_eas_fw_zone, mock_zone_obj):
+        dns_view = 'test_dns_view'
+        port_tenant_id = 'test_tenant_id'
+        tenant_name = 'test_tenant_name'
+        is_external = 'false'
+        mock_zone_obj.create_check_exists.return_value = (
+            mock.Mock(), True)
+        mock_eas_fw_zone.return_value = 'test_eas_forward_zone'
+        self.controller._ensure_dns_zone_availability(
+            dns_view, port_tenant_id,
+            tenant_name, is_external)
+        assert mock_zone_obj.method_calls == [
+            mock.call.create_check_exists(
+                self.ib_cxt.connector,
+                view=dns_view,
+                fqdn=self.test_dns_zone,
+                grid_primary=[mock.ANY],
+                grid_secondaries=None,
+                extattrs='test_eas_forward_zone')
+        ]
