@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+import unittest.mock as mock
 
 from neutron_lib import constants as n_const
 
@@ -107,7 +107,8 @@ class TestPatternBuilder(base.TestCase):
                                 external=True)
 
     def test_get_hostname_for_other_device_owners(self):
-        for dev, patt in const.NEUTRON_DEVICE_OWNER_TO_PATTERN_MAP.items():
+        for dev, patt in list(
+            const.NEUTRON_DEVICE_OWNER_TO_PATTERN_MAP.items()):
             expected_hostname = str.format(
                 "{}.{}", patt.replace('{ip_address}',
                                       self.expected_ip),
@@ -121,7 +122,8 @@ class TestPatternBuilder(base.TestCase):
             '{instance_name}')
         self.pattern_builder.grid_config.external_domain_name_pattern = (
             'external.infoblox.com')
-        for dev, patt in const.NEUTRON_DEVICE_OWNER_TO_PATTERN_MAP.items():
+        for dev, patt in list(
+            const.NEUTRON_DEVICE_OWNER_TO_PATTERN_MAP.items()):
             expected_hostname = str.format(
                 "{}.{}", patt.replace('{ip_address}',
                                       self.expected_ip),
@@ -223,3 +225,31 @@ class TestPatternBuilder(base.TestCase):
         self.assertEqual(
             self.pattern_builder.get_zone_name_pattern(is_external=True),
             self.ib_cxt.grid_config.external_domain_name_pattern)
+
+    def test_validate_pattern_struct(self):
+        pattern_dict = {
+            'network_id': 'subnet',
+            'network_name': 'network',
+            'tenant_id': 'tenant_id',
+            'tenant_name': 'tenant_name',
+            'subnet_name': 'subnet_name',
+            'subnet_id': 'subnet_id'
+        }
+        pattern = '{tenant_id}.{tenant_name}.{subnet_name}'
+        self.pattern_builder._validate_pattern_struct(pattern, pattern_dict)
+        self.assertTrue(True)
+
+    def test_validate_incorrect_pattern_struct(self):
+        pattern_dict = {
+            'network_id': 'subnet',
+            'network_name': 'network',
+            'tenant_id': 'tenant_id',
+            'tenant_name': 'tenant_name',
+            'subnet_name': 'subnet_name',
+            'subnet_id': 'subnet_id'
+        }
+        pattern = '{tenant_id}.{tenant_name}.{subnet_name_invalid}'
+        self.assertRaises(KeyError,
+                          self.pattern_builder._validate_pattern_struct,
+                          pattern,
+                          pattern_dict)
