@@ -13,8 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+import unittest.mock as mock
+
 import netaddr
+
 from neutron_lib import constants as n_const
 
 from networking_infoblox.ipam import requests
