@@ -18,9 +18,9 @@ import sys
 
 from oslo_config import cfg
 
-from neutron.agent.common import config as agent_conf
 from neutron.common import config as common_config
-from neutron import context
+from neutron.conf.agent import common as agent_conf
+from neutron_lib import context
 
 from networking_infoblox.neutron.common import config
 from networking_infoblox.neutron.common import grid
